@@ -22,7 +22,7 @@
 #include "launcher.h"
 #include "panel-addto.h"
 #include "panel-config-global.h"
-#include "mate-panel-applet-frame.h"
+#include "panel-applet-frame.h"
 #include "panel-action-button.h"
 #include "panel-menu-bar.h"
 #include "panel-separator.h"
